@@ -670,6 +670,7 @@ namespace Magick
     std::string artifact(const std::string &name_) const;
 
     // Access/Update a named image attribute
+    void attribute(const std::string name_,const char *value_);
     void attribute(const std::string name_,const std::string value_);
     std::string attribute(const std::string name_ ) const;
 
@@ -1528,6 +1529,9 @@ namespace Magick
     // Map image pixels to a sine wave
     void wave(const double amplitude_=25.0,const double wavelength_=150.0);
 
+    // Removes noise from the image using a wavelet transform.
+    void waveletDenoise(const double threshold_,const double softness_);
+
     // Forces all pixels above the threshold into white while leaving all
     // pixels at or below the threshold unchanged.
     void whiteThreshold(const std::string &threshold_);
