@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -27,6 +27,9 @@ extern "C" {
 #if !defined(MAGICKCORE_QUANTUM_DEPTH)
 #define MAGICKCORE_QUANTUM_DEPTH  16
 #endif
+#if !defined(MagickPathExtent)
+#define MagickPathExtent  MaxTextExtent
+#endif
 
 #if defined(MAGICKCORE_WINDOWS_SUPPORT) && !defined(__MINGW32__) && !defined(__MINGW64__)
 #  define MagickLLConstant(c)  (MagickOffsetType) (c ## i64)
@@ -44,9 +47,9 @@ extern "C" {
   Float_t is not an ABI type.
 */
 #if MAGICKCORE_SIZEOF_FLOAT_T == 0
-typedef float MagickRealType;
+typedef double MagickRealType;
 #elif (MAGICKCORE_SIZEOF_FLOAT_T == MAGICKCORE_SIZEOF_FLOAT)
-typedef float MagickRealType;
+typedef double MagickRealType;
 #elif (MAGICKCORE_SIZEOF_FLOAT_T == MAGICKCORE_SIZEOF_DOUBLE)
 typedef double MagickRealType;
 #elif (MAGICKCORE_SIZEOF_FLOAT_T == MAGICKCORE_SIZEOF_LONG_DOUBLE)
@@ -73,9 +76,9 @@ typedef unsigned char Quantum;
   Float_t is not an ABI type.
 */
 #if MAGICKCORE_SIZEOF_FLOAT_T == 0
-typedef float MagickRealType;
+typedef double MagickRealType;
 #elif (MAGICKCORE_SIZEOF_FLOAT_T == MAGICKCORE_SIZEOF_FLOAT)
-typedef float MagickRealType;
+typedef double MagickRealType;
 #elif (MAGICKCORE_SIZEOF_FLOAT_T == MAGICKCORE_SIZEOF_DOUBLE)
 typedef double MagickRealType;
 #elif (MAGICKCORE_SIZEOF_FLOAT_T == MAGICKCORE_SIZEOF_LONG_DOUBLE)
@@ -122,7 +125,7 @@ typedef unsigned int Quantum;
 #define QuantumFormat  "%u"
 #endif
 #elif (MAGICKCORE_QUANTUM_DEPTH == 64)
-#define MAGICKCORE_HDRI_SUPPORT
+#define MAGICKCORE_HDRI_SUPPORT 1
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
 
@@ -136,7 +139,7 @@ typedef long double Quantum;
 # error "MAGICKCORE_QUANTUM_DEPTH must be one of 8, 16, 32, or 64"
 #endif
 #endif
-#define MagickEpsilon  (1.0e-14)
+#define MagickEpsilon  (1.0e-15)
 #define MagickMaximumValue  1.79769313486231570E+308
 #define MagickMinimumValue   2.22507385850720140E-308
 #define QuantumScale  ((double) 1.0/(double) QuantumRange)
